@@ -15,7 +15,7 @@ use File::chdir;
 use Path::Tiny;
 use YAML::Syck;
 
-our $VERSION = version->new('0.0.4');
+our $VERSION = version->new('0.0.5');
 
 has [qw/ defaults options /] => (
     is => 'rw',
@@ -44,7 +44,10 @@ sub save_session {
     my $file     = $self->history;
     my $sessions = eval { LoadFile( $file ) } || {};
 
-    $sessions->{sessions}{$name} = "$dir" || $CWD;
+    $sessions->{sessions}{$name} = {
+        time => scalar time,
+        dir  => "$dir" || $CWD,
+    };
 
     DumpFile( $file, $sessions );
 
@@ -53,6 +56,7 @@ sub save_session {
 
 sub session_dir {
     my ( $self, $name ) = @_;
+    $name ||= '';
 
     # there are 3 ways of determining a session name:
     #  1. Passed in directly
@@ -67,8 +71,10 @@ sub session_dir {
     my $file     = $self->history;
     my $sessions = eval { LoadFile( $file ) } || {};
 
-    my $dir = $sessions->{sessions}{$name || ''}
-        || $ENV{VTIDE_DIR} || path('.')->absolute;
+    my $dir = ref $sessions->{sessions}{$name} ?
+        $sessions->{sessions}{$name}{dir}
+        : $sessions->{sessions}{$name}
+            || $ENV{VTIDE_DIR} || path('.')->absolute;
 
     my $config = path $dir, '.vtide.yml';
 
@@ -142,7 +148,7 @@ App::VTide::Command - Base class for VTide sub commands
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command version 0.0.4
+This documentation refers to App::VTide::Command version 0.0.5
 
 =head1 SYNOPSIS
 
