@@ -15,7 +15,7 @@ use YAML::Syck;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.0.4');
+our $VERSION = version->new('0.0.5');
 our $NAME    = 'refresh';
 our $OPTIONS = [
     'force|f',
@@ -42,7 +42,10 @@ sub clean_sessions {
     my $sessions = eval { LoadFile( $file ) } || {};
 
     for my $session (keys %{ $sessions->{sessions} }) {
-        my $dir = $sessions->{sessions}{$session};
+        my $dir = ref $sessions->{sessions}{$session}
+            ? $sessions->{sessions}{$session}{dir}
+            : $sessions->{sessions}{$session};
+
         if ( ! -d $dir || ! -f "$dir/.vtide.yml" ) {
             warn "$session ($dir) is missing\n";
             $self->hooks->run('refresh_session_missing', $session, $dir);
@@ -69,7 +72,7 @@ App::VTide::Command::Refresh - Refresh App::VTide configurations
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Refresh version 0.0.4
+This documentation refers to App::VTide::Command::Refresh version 0.0.5
 
 =head1 SYNOPSIS
 
